package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.log.annotation.Log;
import com.usky.common.log.enums.BusinessType;
import com.usky.fire.domain.BaseBuild;
import com.usky.fire.service.BaseBuildService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 建筑信息 前端控制器
 * </p>
 *
 * @author JCB
 * @since 2022-11-22
 */
@RestController
@RequestMapping("/baseBuild")
public class BaseBuildController {


    @Autowired
    private BaseBuildService baseBuildService;

    /**
     * 建筑信息-列表查询
     *
     * @param buildNum  建筑编号
     * @param buildName 建筑名称
     * @param pageNum   当前页
     * @param pageSize  每页条数
     * @return
     */
    @GetMapping("baseBuildList")
    public ApiResult<CommonPage<Object>> baseBuildList(@RequestParam(value = "buildNum", required = false) String buildNum,
                                                       @RequestParam(value = "buildName", required = false) String buildName,
                                                       @RequestParam(value = "pageNum", required = false, defaultValue = "1") Integer pageNum,
                                                       @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize) {
        return ApiResult.success(baseBuildService.baseBuildList(buildNum, buildName, pageNum, pageSize));
    }

    /**
     * 建筑信息-修改
     *
     * @param baseBuild
     * @return
     */
    @Log(title = "建筑信息-修改", businessType = BusinessType.UPDATE)
    @PutMapping("updateBaseBuild")
    public ApiResult<Void> updateBaseBuild(@RequestBody BaseBuild baseBuild) {
        baseBuildService.updateBaseBuild(baseBuild);
        return ApiResult.success();
    }

    /**
     * 建筑信息-删除
     *
     * @param id 主键ID
     * @return
     */
    @Log(title = "建筑信息-删除", businessType = BusinessType.DELETE)
    @DeleteMapping("delBaseBuild")
    public ApiResult<Void> delBaseBuild(@RequestParam(value = "id") Integer id) {
        baseBuildService.delBaseBuild(id);
        return ApiResult.success();
    }


}

